==> igniteui-react-charts-18.5.0-beta.0.tgz: package/esm5/lib/ScatterLineSeries.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { ScatterBase } from "./ScatterBase";
import { UnknownValuePlotting_$type } from "igniteui-react-core";
import { DependencyProperty } from "igniteui-react-core";
import { Point_$type, typeCast, runOn, Number_$type, enumGetBox, markType, markDep } from "igniteui-react-core";
import { OwnedPoint } from "./OwnedPoint";
import { ScatterFrame } from "./ScatterFrame";
import { ScatterLineSeriesView } from "./ScatterLineSeriesView";
import { Defaults } from "./Defaults";
import { PathGeometry } from "igniteui-react-core";
import { Rect } from "igniteui-react-core";
import { ScalerParams } from "./ScalerParams";
import { Clipper } from "igniteui-react-core";
import { List$1 } from "igniteui-react-core";
import { RectUtil } from "igniteui-react-core";
import { PolyLineSegment } from "igniteui-react-core";
import { PathFigure } from "igniteui-react-core";
import { PathFigureCollection } from "igniteui-react-core";
import { Flattener } from "igniteui-react-core";
import { PropertyMetadata } from "igniteui-react-core";
import { boxArray$1, arrayShallowClone } from "igniteui-react-core";
import { isNaN_ } from "igniteui-react-core";
/**
 * @hidden
 */
var ScatterLineSeries = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(ScatterLineSeries, _super);
    function ScatterLineSeries() {
        var _this = _super.call(this) || this;
        _this.ab = ScatterLineSeries.$;
        _this.v0 = new ScatterFrame();
        _this.v2 = new ScatterFrame();
        _this.vy = new ScatterFrame();
        var a = function (b, c, d) {
            var e = _this.c6.indexOf(b.a);
            if (e == -1 || e == 0) {
                return b;
            }
            var f = _this.c6.item(e - 1);
            var g;
            if (!((function () { var h = c.g.tryGetValue(f, g); g = h.p1; return h.ret; })())) {
                return b;
            }
            return g;
        };
        _this.v0.o = a;
        _this.v2.o = a;
        _this.vy.o = a;
        return _this;
    }
    ScatterLineSeries.prototype.get_ex = function () {
        return true;
    };
    ScatterLineSeries.prototype.cg = function () {
        return new ScatterLineSeriesView(this);
    };
    ScatterLineSeries.prototype.wp = function () {
        return true;
    };
    ScatterLineSeries.prototype.ip = function () {
        if (!isNaN_(this.io)) {
            return _super.prototype.ip.call(this);
        }
        return Defaults.x;
    };
    ScatterLineSeries.prototype.f4 = function (a, b) {
        if (this.ud(a, b)) {
            return true;
        }
        if (this.zf(a, b)) {
            return true;
        }
        return false;
    };
    ScatterLineSeries.prototype.zf = function (a, b) {
        var c = this.cj;
        var d = c.dj;
        return this.f5(a, b, d.an);
    };
    ScatterLineSeries.prototype.x6 = function (a, b) {
        var _this = this;
        _super.prototype.x6.call(this, a, b);
        a.m.clear();
        a.u.clear();
        var c = b.by;
        var d = b.bx;
        var e = this.getEffectiveViewport1(b);
        var f = this.hj * this.hj;
        var g = 0;
        if (this.wa != null) {
            g = this.wa.count;
        }
        if (this.wb != null) {
            g = Math.min(this.wb.count, g);
        }
        var h = new ScalerParams(0, c, d, this.vu.d, e);
        var i = ((function () {
            var $ret = new ScalerParams(0, c, d, _this.vu.e, e);
            $ret.b = _this.h2();
            return $ret;
        })());
        var j = arrayShallowClone(this.wa.asArray());
        var k = arrayShallowClone(this.wb.asArray());
        this.xAxis.hn(boxArray$1(j), 0, j.length, h);
        this.yAxis.hn(boxArray$1(k), 0, k.length, i);
        var l = d.top - 10;
        var m = d.bottom + 10;
        var n = d.left - 10;
        var o = d.right + 10;
        var p = ((function () {
            var $ret = new Clipper(1, n, m, o, l, false);
            $ret.i = a.m;
            return $ret;
        })());
        for (var q = 0; q < g;) {
            var r = q;
            ++q;
            if (g > this.w1) {
                while (q < g) {
                    var s = j[q] - j[r];
                    var t = k[q] - k[r];
                    var u = s * s + t * t;
                    if (u >= f) {
                        break;
                    }
                    ++q;
                }
                p.j(this.zm(j, k, r, q - 1));
            }
            else {
                var v = new OwnedPoint();
                v.c = { $type: Point_$type, x: j[r], y: k[r] };
                v.a = this.c6.item(r);
                if (!a.u.containsKey(v.a)) {
                    a.u.addItem(v.a, v);
                }
            }
        }
        if (g > this.w1) {
            p.i = null;
        }
    };
    ScatterLineSeries.prototype.zm = function (a, b, c, d) {
        if (c == d) {
            return { $type: Point_$type, x: a[c], y: b[c] };
        }
        var e = 0;
        var f = 0;
        var g = (d - c + 1);
        for (var h = c; h <= d; ++h) {
            e += a[h];
            f += b[h];
        }
        return { $type: Point_$type, x: e / g, y: f / g };
    };
    ScatterLineSeries.prototype.get_wj = function () {
        return true;
    };
    ScatterLineSeries.prototype.yh = function (a, b) {
        b.c7(false);
        _super.prototype.yh.call(this, a, b);
        var c = this.getEffectiveViewport1(b);
        var d = new Rect(0, b.bx.left, b.bx.top, b.bx.width, b.bx.height);
        d = RectUtil.t(d, this.hk, this.hk);
        this.ya(a, new Clipper(0, d, false));
        var e = typeCast(ScatterLineSeriesView.$, b);
        this.v7.az(this, this.wo(), runOn(this, this.vi));
        var f = false;
        var g = this.v7.b;
        if (g != null) {
            f = true;
        }
        if (f) {
            this.x2(-1, this.wa.count, b.q);
        }
        this.v7.ad(e.dj, true, false, true, false);
        this.zk(e.dj, a.m.count, function (h) { return a.m._inner[h].x; }, function (h) { return a.m._inner[h].y; }, this.ze, this.hj);
    };
    ScatterLineSeries.prototype.zk = function (a, b, c, d, e, f) {
        var g = new PathGeometry();
        a.an = g;
        g.c = new PathFigureCollection();
        var h = new List$1(PolyLineSegment.$, 0);
        var i = 0;
        for (var j = 0; j < b; j++) {
            if (isNaN_(c(j)) || isNaN_(d(j))) {
                var k = j - i;
                if (k > 0) {
                    if (e == 1 || h.count == 0) {
                        var l = new PolyLineSegment();
                        h.add(l);
                    }
                    this.zj(h._inner[h.count - 1]._points, i, j - 1, c, d, f);
                }
                i = j + 1;
            }
        }
        if (e == 1 || h.count == 0) {
            var m = new PolyLineSegment();
            h.add(m);
        }
        this.zj(h._inner[h.count - 1]._points, i, b - 1, c, d, f);
        var _loop_1 = function (n) {
            var o = h._inner[n];
            if (o._points.count > 0) {
                var p = ((function () {
                    var $ret = new PathFigure();
                    $ret.startPoint = o._points._inner[0];
                    return $ret;
                })());
                p._segments.add(o);
                g.c.add(p);
            }
        };
        for (var n = 0; n < h.count; n++) {
            _loop_1(n);
        }
    };
    ScatterLineSeries.prototype.zg = function (a, b, c, d, e, f) {
        var g = new List$1(Number_$type, 0);
        var h = d;
        var i = e;
        var j = i - h + 1;
        while (j > 0) {
            if (j <= 512) {
                Flattener.c(g, b, c, h, i, f);
                h = i + 1;
            }
            else {
                var k = h + 512 - 1;
                Flattener.c(g, b, c, h, k, f);
                h = k + 1;
            }
            j = i - h + 1;
        }
        return g;
    };
    ScatterLineSeries.prototype.zj = function (a, b, c, d, e, f) {
        if (c > -1) {
            var g = !isNaN_(this.io) ? f : 1;
            var h = this.zg(new List$1(Number_$type, 0), d, e, b, c, g);
            var i = void 0;
            for (var j = 0; j < h.count; j++) {
                i = h.item(j);
                a.add({ $type: Point_$type, x: d(i), y: e(i) });
            }
        }
    };
    ScatterLineSeries.prototype.o8 = function (a, b, c, d) {
        _super.prototype.o8.call(this, a, b, c, d);
        switch (b) {
            case ScatterLineSeries.$$p[0]:
                this.pp(false);
                this.ol();
                break;
        }
    };
    ScatterLineSeries.$t = markType(ScatterLineSeries, 'ScatterLineSeries', ScatterBase.$);
    ScatterLineSeries.$$p = markDep(DependencyProperty, PropertyMetadata, ScatterLineSeries, 'raisePropertyChanged', ['UnknownValuePlotting:ze:zl', [UnknownValuePlotting_$type, enumGetBox(UnknownValuePlotting_$type, 1)]]);
    return ScatterLineSeries;
}(ScatterBase));
export { ScatterLineSeries };

==> igniteui-react-charts-18.7.4-beta.0.tgz: package/esm5/lib/ScatterLineSeries.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { ScatterBase } from "./ScatterBase";
import { UnknownValuePlotting_$type } from "igniteui-react-core";
import { DependencyProperty } from "igniteui-react-core";
import { Point_$type, typeCast, runOn, Number_$type, enumGetBox, markType, markDep } from "igniteui-react-core";
import { OwnedPoint } from "./OwnedPoint";
import { ScatterFrame } from "./ScatterFrame";
import { ScatterLineSeriesView } from "./ScatterLineSeriesView";
import { Defaults } from "./Defaults";
import { PathGeometry } from "igniteui-react-core";
import { Rect } from "igniteui-react-core";
import { ScalerParams } from "./ScalerParams";
import { Clipper } from "igniteui-react-core";
import { List$1 } from "igniteui-react-core";
import { RectUtil } from "igniteui-react-core";
import { PolyLineSegment } from "igniteui-react-core";
import { PathFigure } from "igniteui-react-core";
import { PathFigureCollection } from "igniteui-react-core";
import { Flattener } from "igniteui-react-core";
import { PropertyMetadata } from "igniteui-react-core";
import { boxArray$1, arrayShallowClone } from "igniteui-react-core";
import { isNaN_ } from "igniteui-react-core";
/**
 * @hidden
 */
var ScatterLineSeries = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(ScatterLineSeries, _super);
    function ScatterLineSeries() {
        var _this = _super.call(this) || this;
        _this.ab = ScatterLineSeries.$;
        _this.yx = new ScatterFrame();
        _this.yz = new ScatterFrame();
        _this.yv = new ScatterFrame();
        var a = function (b, c, d) {
            var e = _this.dm.indexOf(b.a);
            if (e == -1 || e == 0) {
                return b;
            }
            var f = _this.dm.item(e - 1);
            var g;
            if (!((function () { var h = c.g.tryGetValue(f, g); g = h.p1; return h.ret; })())) {
                return b;
            }
            return g;
        };
        _this.yx.o = a;
        _this.yz.o = a;
        _this.yv.o = a;
        return _this;
    }
    ScatterLineSeries.prototype.bj = function () {
        return new ScatterLineSeries();
    };
    ScatterLineSeries.prototype.get_fj = function () {
        return true;
    };
    ScatterLineSeries.prototype.cr = function () {
        return new ScatterLineSeriesView(this);
    };
    ScatterLineSeries.prototype.zr = function () {
        return true;
    };
    ScatterLineSeries.prototype.jj = function () {
        if (!isNaN_(this.ji)) {
            return _super.prototype.jj.call(this);
        }
        return Defaults.x;
    };
    ScatterLineSeries.prototype.gv = function (a, b) {
        if (this.xc(a, b)) {
            return true;
        }
        if (this.acj(a, b)) {
            return true;
        }
        return false;
    };
    ScatterLineSeries.prototype.acj = function (a, b) {
        var c = this.cu;
        var d = c.dl;
        return this.gw(a, b, d.an);
    };
    ScatterLineSeries.prototype.aba = function (a, b) {
        var _this = this;
        _super.prototype.aba.call(this, a, b);
        a.m.clear();
        a.u.clear();
        var c = b.by;
        var d = b.bx;
        var e = this.getEffectiveViewport1(b);
        var f = this.ic * this.ic;
        var g = 0;
        if (this.zc != null) {
            g = this.zc.count;
        }
        if (this.zd != null) {
            g = Math.min(this.zd.count, g);
        }
        var h = new ScalerParams(0, c, d, this.yr.d, e);
        var i = ((function () {
            var $ret = new ScalerParams(0, c, d, _this.yr.e, e);
            $ret.b = _this.ix();
            return $ret;
        })());
        var j = arrayShallowClone(this.zc.asArray());
        var k = arrayShallowClone(this.zd.asArray());
        this.xAxis.ho(boxArray$1(j), 0, j.length, h);
        this.yAxis.ho(boxArray$1(k), 0, k.length, i);
        var l = d.top - 10;
        var m = d.bottom + 10;
        var n = d.left - 10;
        var o = d.right + 10;
        var p = ((function () {
            var $ret = new Clipper(1, n, m, o, l, false);
            $ret.i = a.m;
            return $ret;
        })());
        for (var q = 0; q < g;) {
            var r = q;
            ++q;
            if (g > this.z4) {
                while (q < g) {
                    var s = j[q] - j[r];
                    var t = k[q] - k[r];
                    var u = s * s + t * t;
                    if (isNaN_(u) || u >= f) {
                        break;
                    }
                    ++q;
                }
                p.j(this.acq(j, k, r, q - 1));
            }
            else {
                var v = new OwnedPoint();
                v.c = { $type: Point_$type, x: j[r], y: k[r] };
                v.a = this.dm.item(r);
                if (!a.u.containsKey(v.a)) {
                    a.u.addItem(v.a, v);
                }
            }
        }
        if (g > this.z4) {
            p.i = null;
        }
    };
    ScatterLineSeries.prototype.acq = function (a, b, c, d) {
        if (c == d) {
            return { $type: Point_$type, x: a[c], y: b[c] };
        }
        var e = 0;
        var f = 0;
        var g = (d - c + 1);
        for (var h = c; h <= d; ++h) {
            e += a[h];
            f += b[h];
        }
        return { $type: Point_$type, x: e / g, y: f / g };
    };
    ScatterLineSeries.prototype.get_zl = function () {
        return true;
    };
    ScatterLineSeries.prototype.abl = function (a, b) {
        b.c9(false);
        _super.prototype.abl.call(this, a, b);
        var c = this.getEffectiveViewport1(b);
        var d = new Rect(0, b.bx.left, b.bx.top, b.bx.width, b.bx.height);
        d = RectUtil.t(d, this.id, this.id);
        this.abe(a, new Clipper(0, d, false));
        var e = typeCast(ScatterLineSeriesView.$, b);
        this.y4.az(this, this.zq(), runOn(this, this.yk));
        var f = false;
        var g = this.y4.b;
        if (g != null) {
            f = true;
        }
        if (f) {
            this.aa6(-1, this.zc.count, b.q);
        }
        this.y4.ad(e.dl, true, false, true, false);
        this.aco(e.dl, a.m.count, function (h) { return a.m._inner[h].x; }, function (h) { return a.m._inner[h].y; }, this.aci, this.ic);
    };
    ScatterLineSeries.prototype.aco = function (a, b, c, d, e, f) {
        var g = new PathGeometry();
        a.an = g;
        g.c = new PathFigureCollection();
        var h = new List$1(PolyLineSegment.$, 0);
        var i = 0;
        for (var j = 0; j < b; j++) {
            if (isNaN_(c(j)) || isNaN_(d(j))) {
                var k = j - i;
                if (k > 0) {
                    if (e == 1 || h.count == 0) {
                        var l = new PolyLineSegment();
                        h.add(l);
                    }
                    this.acn(h._inner[h.count - 1]._points, i, j - 1, c, d, f);
                }
                i = j + 1;
            }
        }
        if (e == 1 || h.count == 0) {
            var m = new PolyLineSegment();
            h.add(m);
        }
        this.acn(h._inner[h.count - 1]._points, i, b - 1, c, d, f);
        var _loop_1 = function (n) {
            var o = h._inner[n];
            if (o._points.count > 0) {
                var p = ((function () {
                    var $ret = new PathFigure();
                    $ret.startPoint = o._points._inner[0];
                    return $ret;
                })());
                p._segments.add(o);
                g.c.add(p);
            }
        };
        for (var n = 0; n < h.count; n++) {
            _loop_1(n);
        }
    };
    ScatterLineSeries.prototype.ack = function (a, b, c, d, e, f) {
        var g = new List$1(Number_$type, 0);
        var h = d;
        var i = e;
        var j = i - h + 1;
        while (j > 0) {
            if (j <= 512) {
                Flattener.c(g, b, c, h, i, f);
                h = i + 1;
            }
            else {
                var k = h + 512 - 1;
                Flattener.c(g, b, c, h, k, f);
                h = k + 1;
            }
            j = i - h + 1;
        }
        return g;
    };
    ScatterLineSeries.prototype.acn = function (a, b, c, d, e, f) {
        if (c > -1) {
            var g = !isNaN_(this.ji) ? f : 1;
            var h = this.ack(new List$1(Number_$type, 0), d, e, b, c, g);
            var i = void 0;
            for (var j = 0; j < h.count; j++) {
                i = h.item(j);
                a.add({ $type: Point_$type, x: d(i), y: e(i) });
            }
        }
    };
    ScatterLineSeries.prototype.q7 = function (a, b, c, d) {
        _super.prototype.q7.call(this, a, b, c, d);
        switch (b) {
            case ScatterLineSeries.$$p[0]:
                this.rp(false);
                this.qj();
                break;
        }
    };
    ScatterLineSeries.$t = markType(ScatterLineSeries, 'ScatterLineSeries', ScatterBase.$);
    ScatterLineSeries.$$p = markDep(DependencyProperty, PropertyMetadata, ScatterLineSeries, 'raisePropertyChanged', ['UnknownValuePlotting:aci:acp', [UnknownValuePlotting_$type, enumGetBox(UnknownValuePlotting_$type, 1)]]);
    return ScatterLineSeries;
}(ScatterBase));
export { ScatterLineSeries };
